## Version 0.13.1 (2021-06-07)
### 👷 Bug fixes

- MANIFEST: include changelog

### 🤖 Continuous integration

- add deb packages

## Version 0.13.0 (2021-06-07)
### 🎉 New features

- WorkOrder: make budget required and positive

### 📝 Documentation

- licence: update licence dates

### 🤖 Continuous integration

- use gitlab-ci templates